pub enum Orientation {
CounterClockwise,
Collinear,
Clockwise,
}Expand description
Which side of a directed line a point falls on.
Returned by orient2d.
Variants
CounterClockwise
c lies strictly left of the directed line a -> b
(a counter-clockwise turn).
Collinear
c lies exactly on the line through a and b.
Clockwise
c lies strictly right of the directed line a -> b
(a clockwise turn).